@@ -16,11 +16,11 @@ See the License for the specific language governing permissions and
 limitations under the License.
 
 :license: Apache License 2.0
-:version: 0.1.6
+:version: 0.1.7
 """
 
 # Module version
-__version_info__ = (0, 1, 6)
+__version_info__ = (0, 1, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -56,7 +56,8 @@ class Config(object):
     def __init__(self, version=2.0, content_type="application/json-rpc",
                  user_agent=None, use_jsonclass=True,
                  serialize_method='_serialize',
-                 ignore_attribute='_ignore'):
+                 ignore_attribute='_ignore',
+                 serialize_handlers=None):
         """
         Sets up a configuration of JSONRPClib
 
@@ -72,6 +73,9 @@ class Config(object):
                                  custom class object which holds strings and/or
                                  references of the attributes the class
                                  translator should ignore.
+        :param serialize_handlers: A dictionary of dump handler functions by
+                                   type for additional type support and for
+                                   overriding dump of built-in types in utils
         """
         # JSON-RPC specification
         self.version = version
@@ -104,5 +108,11 @@ class Config(object):
         # references of the attributes the class translator should ignore.
         self.ignore_attribute = ignore_attribute
 
+        # The list of serialize handler functions for jsonclass dump.
+        # Used for handling additional types and overriding built-in types.
+        # Functions are expected to have the same parameters as jsonclass dump
+        # (possibility to call standard jsonclass dump function within).
+        self.serialize_handlers = serialize_handlers or {}
+
 # Default configuration
 DEFAULT = Config()
